==> kubernetes-model-core-6.2.0-sources.jar: io/fabric8/kubernetes/api/builder/VisitorWiretap.java <==
package io.fabric8.kubernetes.api.builder;

import java.util.Map.Entry;
import java.util.Collection;
import java.lang.Class;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Collections;
import java.util.function.Predicate;
public final class VisitorWiretap<T> implements Visitor<T>{
  private VisitorWiretap(Visitor<T> delegate,Collection<VisitorListener> listeners) {
    this.delegate = delegate;
    this.listeners = listeners;
  }
  private final Collection<VisitorListener> listeners;
  private final Visitor<T> delegate;
  public static <T>VisitorWiretap<T> create(Visitor<T> visitor,Collection<VisitorListener> listeners) {
    if (visitor instanceof VisitorWiretap) {
      return (VisitorWiretap<T>) visitor;
    }
    return new VisitorWiretap<T>(visitor, listeners);
  }
  public Class<T> getType() {
    return delegate.getType();
  }
  public void visit(T target) {
    listeners.forEach(l -> l.beforeVisit(delegate, Collections.emptyList(), target));
    delegate.visit(target);
    listeners.forEach(l -> l.afterVisit(delegate, Collections.emptyList(), target));
  }
  public int order() {
    return delegate.order();
  }
  public void visit(List<Entry<String,Object>> path,T target) {
    listeners.forEach(l -> l.beforeVisit(delegate, path, target));
    delegate.visit(path, target);
    listeners.forEach(l -> l.afterVisit(delegate, path, target));
  }
  public <F>Boolean canVisit(List<Entry<String,Object>> path,F target) {
    boolean canVisit = delegate.canVisit(path, target);
    listeners.forEach(l -> l.onCheck(delegate, canVisit, target));
    return canVisit;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/builder/VisitorWiretap.java <==
package io.fabric8.kubernetes.api.builder;

import java.util.Map.Entry;
import java.util.Collection;
import java.lang.Class;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Collections;
import java.util.function.Predicate;
public final class VisitorWiretap<T> implements Visitor<T>{
  private VisitorWiretap(Visitor<T> delegate,Collection<VisitorListener> listeners) {
    this.delegate = delegate;
    this.listeners = listeners;
  }
  private final Collection<VisitorListener> listeners;
  private final Visitor<T> delegate;
  public static <T>VisitorWiretap<T> create(Visitor<T> visitor,Collection<VisitorListener> listeners) {
    if (visitor instanceof VisitorWiretap) {
      return (VisitorWiretap<T>) visitor;
    }
    return new VisitorWiretap<T>(visitor, listeners);
  }
  public Class<T> getType() {
    return delegate.getType();
  }
  public void visit(T target) {
    for (VisitorListener l : listeners) {
      l.beforeVisit(delegate, Collections.emptyList(), target);
    }
    delegate.visit(target);
    for (VisitorListener l : listeners) {
      l.afterVisit(delegate, Collections.emptyList(), target);
    }
  }
  public int order() {
    return delegate.order();
  }
  public void visit(List<Entry<String,Object>> path,T target) {
    for (VisitorListener l : listeners) {
      l.beforeVisit(delegate, path, target);
    }
    delegate.visit(path, target);
    for (VisitorListener l : listeners) {
      l.afterVisit(delegate, path, target);
    }
  }
  public <F>Boolean canVisit(List<Entry<String,Object>> path,F target) {
    boolean canVisit = delegate.canVisit(path, target);
    for (VisitorListener l : listeners) {
      l.onCheck(delegate, canVisit, target);
    }

    return canVisit;
  }
  
}
